diff src/redisplay.c @ 2552:166ed8151e62

[xemacs-hg @ 2005-02-03 16:30:33 by james] Don't define this to c_this, and rename variables currently named this. See xemacs-patches message with ID <psbrb1ehjl.fsf@diannao.ittc.ku.edu>.
author james
date Thu, 03 Feb 2005 16:30:38 +0000
parents 9f70af3ac939
children facf3239ba30
line wrap: on
line diff
--- a/src/redisplay.c	Thu Feb 03 16:14:08 2005 +0000
+++ b/src/redisplay.c	Thu Feb 03 16:30:38 2005 +0000
@@ -4106,20 +4106,20 @@
       /* A string.  Add to the display line and check for %-constructs
          within it. */
 
-      Ibyte *this = XSTRING_DATA (elt);
-
-      while ((pos < max_pos || max_pos == -1) && *this)
+      Ibyte *this_str = XSTRING_DATA (elt);
+
+      while ((pos < max_pos || max_pos == -1) && *this_str)
         {
-          Ibyte *last = this;
-
-          while (*this && *this != '%')
-            this++;
-
-          if (this != last)
+          Ibyte *last = this_str;
+
+          while (*this_str && *this_str != '%')
+            this_str++;
+
+          if (this_str != last)
             {
               /* No %-construct */
               Charcount size =
-		bytecount_to_charcount (last, this - last);
+		bytecount_to_charcount (last, this_str - last);
 
 	      if (size <= *offset)
 		*offset -= size;
@@ -4134,32 +4134,32 @@
 		  *offset = 0;
 		}
             }
-          else /* *this == '%' */
+          else /* *this_str == '%' */
             {
               Charcount spec_width = 0;
 
-              this++; /* skip over '%' */
+              this_str++; /* skip over '%' */
 
               /* We can't allow -ve args due to the "%-" construct.
                * Argument specifies minwidth but not maxwidth
                * (maxwidth can be specified by
                * (<negative-number> . <stuff>) modeline elements)
                */
-              while (isdigit (*this))
+              while (isdigit (*this_str))
                 {
-                  spec_width = spec_width * 10 + (*this - '0');
-                  this++;
+                  spec_width = spec_width * 10 + (*this_str - '0');
+                  this_str++;
                 }
               spec_width += pos;
 
-              if (*this == 'M')
+              if (*this_str == 'M')
                 {
                   pos = generate_fstring_runes (w, data, pos, spec_width,
                                                 max_pos, Vglobal_mode_string,
                                                 depth, max_pixsize, findex,
                                                 type, offset, cur_ext);
                 }
-              else if (*this == '-')
+              else if (*this_str == '-')
                 {
                   Charcount num_to_add;
 
@@ -4186,9 +4186,9 @@
                     pos = add_string_to_fstring_db_runes
                       (data, (const Ibyte *) "-", pos, pos, max_pos);
                 }
-              else if (*this != 0)
+              else if (*this_str != 0)
                 {
-                  Ichar ch = itext_ichar (this);
+                  Ichar ch = itext_ichar (this_str);
                   Ibyte *str;
 		  Charcount size;
 
@@ -4215,9 +4215,9 @@
 		    }
                 }
 
               /* NOT this++.  There could be any sort of character at
                  the current position. */
-              INC_IBYTEPTR (this);
+              INC_IBYTEPTR (this_str);
             }
 
           if (max_pixsize > 0)
@@ -4215,9 +4215,9 @@
                 }
 
-              /* NOT this++.  There could be any sort of character at
+              /* NOT this_str++.  There could be any sort of character at
                  the current position. */